PlayerQueuesEndpoint class

PlayerQueue related endpoints/data for Music Assistant.

Constructors

PlayerQueuesEndpoint(MusicAssistantClient _client)
Create a PlayerQueuesEndpoint instance

Properties

hashCode int
The hash code for this object.
no setterinherited
keys Iterable<String>
Get a list of all fetched player queue ids.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<PlayerQueue>
Get a list of all fetched player queues.
no setter

Methods

clear(String queueId) Future<void>
Send CLEAR QUEUE command to given queue.
deleteItem(String queueId, dynamic itemIdOrIndex) Future<void>
Delete item (by id or index) from the queue.
dontStopTheMusic(String queueId, bool dontStopTheMusicEnabled) Future<void>
Configure Don't stop the music setting on the queue.
fetchState() Future<void>
Fetch initial state once the server is connected.
getActiveQueue(String playerId) Future<PlayerQueue?>
Return the current active/synced queue for a player.
moveDown(String queueId, String queueItemId) Future<void>
Move given queue item one place down in the queue.
moveItem(String queueId, String queueItemId, {int posShift = 1}) Future<void>
Move queue item x up/down the queue.
moveNext(String queueId, String queueItemId) Future<void>
Move given queue item as next up in the queue.
moveUp(String queueId, String queueItemId) Future<void>
Move given queue item one place up in the queue.
next(String queueId) Future<void>
Send NEXT TRACK command to given queue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(String queueId) Future<void>
Send PAUSE command to given queue.
play(String queueId) Future<void>
Send PLAY command to given queue.
playIndex(String queueId, dynamic index, {int seekPosition = 0, bool fadeIn = false}) Future<void>
Play item at index (or item_id) X in queue.
playMedia(String queueId, dynamic media, {QueueOption? option, bool radioMode = false, String? startItem}) Future<void>
Play media item(s) on the given queue.
playPause(String queueId) Future<void>
Toggle play/pause on given playerqueue.
previous(String queueId) Future<void>
Send PREVIOUS TRACK command to given queue.
repeat(String queueId, RepeatMode repeatMode) Future<void>
Configure repeat mode on the queue.
resume(String queueId, {bool? fadeIn}) Future<void>
Handle RESUME command for given queue.
seek(String queueId, int position) Future<void>
Handle SEEK command for given queue.
shuffle(String queueId, bool shuffleEnabled) Future<void>
Configure shuffle mode on the queue.
skip(String queueId, int seconds) Future<void>
Handle SKIP command for given queue.
stop(String queueId) Future<void>
Send STOP command to given queue.
toString() String
A string representation of this object.
inherited
transfer(String sourceQueueId, String targetQueueId, {bool? autoPlay}) Future<void>
Transfer queue to another queue.

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String queueId) PlayerQueue?
Get a fetched player queue by id.