AuthToken class

Authentication token model.

Annotations
  • @JsonSerializable.new()

Constructors

AuthToken({required String tokenId, required String userId, required String tokenHash, required String name})
AuthToken.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
getter/setter pair
expiresAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLongLived bool
getter/setter pair
lastUsedAt DateTime?
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenHash String
getter/setter pair
tokenId String
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited