MediaType enum
Enum for MediaType.
Values
- artist → const MediaType
-
const MediaType('artist') - album → const MediaType
-
const MediaType('album') - track → const MediaType
-
const MediaType('track') - playlist → const MediaType
-
const MediaType('playlist') - radio → const MediaType
-
const MediaType('radio') - audiobook → const MediaType
-
const MediaType('audiobook') - podcast → const MediaType
-
const MediaType('podcast') - podcastEpisode → const MediaType
-
const MediaType('podcast_episode') - folder → const MediaType
-
const MediaType('folder') - announcement → const MediaType
-
const MediaType('announcement') - flowStream → const MediaType
-
const MediaType('flow_stream') - pluginSource → const MediaType
-
const MediaType('plugin_source') - soundEffect → const MediaType
-
const MediaType('sound_effect') - genre → const MediaType
-
const MediaType('genre') - unknown → const MediaType
-
const MediaType('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited