PlayerMedia class

Metadata of Media loading/loaded into a player.

Annotations
  • @JsonSerializable.new()

Constructors

PlayerMedia()
PlayerMedia.fromJson(Map<String, dynamic> json)
factory

Properties

album String?
getter/setter pair
artist String?
getter/setter pair
correctedElapsedTime double?
Return the corrected/realtime elapsed time.
no setter
customData Map<String, dynamic>?
getter/setter pair
duration int?
getter/setter pair
elapsedTime int?
getter/setter pair
elapsedTimeLastUpdated double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
getter/setter pair
mediaType MediaType
getter/setter pair
palette MediaItemPalette?
getter/setter pair
queueItemId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId String?
getter/setter pair
title String?
getter/setter pair
uri String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited