PlayerOption class

Model for a PlayerOption.

Annotations
  • @JsonSerializable.new()

Constructors

PlayerOption()
PlayerOption.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
getter/setter pair
maxValue num?
getter/setter pair
minValue num?
getter/setter pair
name String?
getter/setter pair
options List<PlayerOptionEntry>?
getter/setter pair
readOnly bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step num?
getter/setter pair
translationKey String
getter/setter pair
translationParams List<String>?
getter/setter pair
type PlayerOptionType?
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited