PlayerQueue class

Representation of (the state of) a PlayerQueue within Music Assistant.

Annotations
  • @JsonSerializable.new()

Constructors

PlayerQueue()
PlayerQueue.fromJson(Map<String, dynamic> input)
factory

Properties

active bool?
getter/setter pair
available bool?
getter/setter pair
correctedElapsedTime double
no setter
currentIndex int?
getter/setter pair
currentItem QueueItem?
getter/setter pair
displayName String?
getter/setter pair
dontStopTheMusicEnabled bool
getter/setter pair
elapsedTime double
getter/setter pair
elapsedTimeLastUpdated double?
getter/setter pair
extraAttributes Map<String, dynamic>
getter/setter pair
flowMode bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
indexInBuffer int?
getter/setter pair
items int?
getter/setter pair
nextItem QueueItem?
getter/setter pair
queueId String?
getter/setter pair
radioSource List
getter/setter pair
repeatMode RepeatMode
getter/setter pair
resumePos int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shuffleEnabled bool
getter/setter pair
state PlaybackState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited