QueueItem class

Representation of a queue item.

Annotations
  • @JsonSerializable.new()

Constructors

QueueItem()
QueueItem.fromJson(Map<String, dynamic> json)
factory

Properties

available bool
getter/setter pair
duration int?
getter/setter pair
extraAttributes Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image MediaItemImage?
getter/setter pair
index int
getter/setter pair
mediaItem Map<String, dynamic>?
getter/setter pair
name String?
getter/setter pair
queueId String?
getter/setter pair
queueItemId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortIndex int
getter/setter pair
streamdetails StreamDetails?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited