StreamType enum

Enum for the type of streamdetails.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'value')

Values

http → const StreamType
const StreamType('http')
encryptedHttp → const StreamType
const StreamType('encrypted_http')
hls → const StreamType
const StreamType('hls')
icy → const StreamType
const StreamType('icy')
shoutcast → const StreamType
const StreamType('shoutcast')
inBand → const StreamType
const StreamType('in_band')
localFile → const StreamType
const StreamType('local_file')
namedPipe → const StreamType
const StreamType('named_pipe')
otherFfmpeg → const StreamType
const StreamType('other_ffmpeg')
custom → const StreamType
const StreamType('custom')
unknown → const StreamType
const StreamType('unknown')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StreamType>
A constant List of the values in this enum, in order of their declaration.