UserAuthProvider class

Link between a User and an Authentication Provider.

Annotations
  • @JsonSerializable.new()

Constructors

UserAuthProvider({required String linkId, required String userId, required AuthProviderType providerType, required String providerUserId})
UserAuthProvider.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
linkId String
getter/setter pair
providerType AuthProviderType
getter/setter pair
providerUserId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited