models library
Classes
- AudioFormat
- Model for AudioFormat details.
- AuthToken
- Authentication token model.
- DeviceInfo
- Model for a player's device info.
- MediaItemImage
- Model for a image.
- MediaItemPalette
- Color palette derived from a MediaItem's artwork.
- MultiPartPath
- Model for a multipart path. Used when a stream is split into multiple parts, e.g. chapters.
- OutputProtocol
- Represents an output protocol for a player.
- Player
- Representation of (the state of) a player within Music Assistant.
- PlayerMedia
- Metadata of Media loading/loaded into a player.
- PlayerOption
- Model for a PlayerOption.
- PlayerOptionEntry
- A single choice.
- PlayerQueue
- Representation of (the state of) a PlayerQueue within Music Assistant.
- PlayerSoundMode
- Model for a player sound mode.
- PlayerSource
- Model for a player source.
- QueueItem
- Representation of a queue item.
- StreamDetails
- Model for streamdetails.
- StreamMetadata
- Metadata of a live broadcast / media stream.
- User
- User model.
- UserAuthProvider
- Link between a User and an Authentication Provider.
Enums
- AuthProviderType
- Authentication provider type enum.
- ContentType
- Enum with audio content/container types supported by ffmpeg.
- CoreState
- Enum representing the core state of the Music Assistant server.
- EventType
- Enum with possible Events.
- IdentifierType
- Types of identifiers/connections for a device.
- ImageType
- Enum with image types.
- MediaType
- Enum for MediaType.
- PlaybackState
- Enum for the (playback)state of a player.
- PlayerFeature
- Enum with possible Player features.
- PlayerOptionType
- Enum for the type of a Player Option.
- PlayerType
- QueueOption
- Enum representation of the queue (play) options.
- RepeatMode
- Enum with repeat modes.
- StreamType
- Enum for the type of streamdetails.
- UserRole
- User role enum.