ContentType enum
Enum with audio content/container types supported by ffmpeg.
Values
- ogg → const ContentType
-
const ContentType('ogg') - wav → const ContentType
-
const ContentType('wav') - aiff → const ContentType
-
const ContentType('aiff') - mpeg → const ContentType
-
const ContentType('mpeg') - m4a → const ContentType
-
const ContentType('m4a') - mp4 → const ContentType
-
const ContentType('mp4') - mp4a → const ContentType
-
const ContentType('mp4a') - m4b → const ContentType
-
const ContentType('m4b') - dsf → const ContentType
-
const ContentType('dsf') - flac → const ContentType
-
const ContentType('flac') - mp3 → const ContentType
-
const ContentType('mp3') - wma → const ContentType
-
const ContentType('wma') - wmav2 → const ContentType
-
const ContentType('wmav2') - wmapro → const ContentType
-
const ContentType('wmapro') - wavpack → const ContentType
-
const ContentType('wavpack') - tak → const ContentType
-
const ContentType('tak') - ape → const ContentType
-
const ContentType('ape') - musepack → const ContentType
-
const ContentType('mpc') - aac → const ContentType
-
const ContentType('aac') - alac → const ContentType
-
const ContentType('alac') - opus → const ContentType
-
const ContentType('opus') - vorbis → const ContentType
-
const ContentType('vorbis') - ac3 → const ContentType
-
const ContentType('ac3') - eac3 → const ContentType
-
const ContentType('eac3') - dts → const ContentType
-
const ContentType('dts') - truehd → const ContentType
-
const ContentType('truehd') - dtshd → const ContentType
-
const ContentType('dtshd') - dtsx → const ContentType
-
const ContentType('dtsx') - cook → const ContentType
-
const ContentType('cook') - ra144 → const ContentType
-
const ContentType('ralf') - mp2 → const ContentType
-
const ContentType('mp2') - mp1 → const ContentType
-
const ContentType('mp1') - dra → const ContentType
-
const ContentType('dra') - atrac3 → const ContentType
-
const ContentType('atrac3') - pcmS16le → const ContentType
-
const ContentType('s16le') - pcmS24le → const ContentType
-
const ContentType('s24le') - pcmS32le → const ContentType
-
const ContentType('s32le') - pcmF32le → const ContentType
-
const ContentType('f32le') - pcmF64le → const ContentType
-
const ContentType('f64le') - pcmS16be → const ContentType
-
const ContentType('s16be') - pcmS24be → const ContentType
-
const ContentType('s24be') - pcmS32be → const ContentType
-
const ContentType('s32be') - pcmBluray → const ContentType
-
const ContentType('pcm_bluray') - pcmDvd → const ContentType
-
const ContentType('pcm_dvd') - adpcmIma → const ContentType
-
const ContentType('adpcm_ima_qt') - adpcmMs → const ContentType
-
const ContentType('adpcm_ms') - adpcmSwf → const ContentType
-
const ContentType('adpcm_swf') - dsdLsbf → const ContentType
-
const ContentType('dsd_lsbf') - dsdMsbf → const ContentType
-
const ContentType('dsd_msbf') - dsdLsbfPlanar → const ContentType
-
const ContentType('dsd_lsbf_planar') - dsdMsbfPlanar → const ContentType
-
const ContentType('dsd_msbf_planar') - amr → const ContentType
-
const ContentType('amr_nb') - amrWb → const ContentType
-
const ContentType('amr_wb') - speex → const ContentType
-
const ContentType('speex') - pcmAlaw → const ContentType
-
const ContentType('alaw') - pcmMulaw → const ContentType
-
const ContentType('mulaw') - g722 → const ContentType
-
const ContentType('g722') - g726 → const ContentType
-
const ContentType('g726') - pcm → const ContentType
-
const ContentType('pcm') - nut → const ContentType
-
const ContentType('nut') - unknown → const ContentType
-
const ContentType('?')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ContentType> - A constant List of the values in this enum, in order of their declaration.