IdentifierType enum
Types of identifiers/connections for a device.
Values
- macAddress → const IdentifierType
-
const IdentifierType('mac_address') - serialNumber → const IdentifierType
-
const IdentifierType('serial_number') - uuid → const IdentifierType
-
const IdentifierType('uuid') - castUuid → const IdentifierType
-
const IdentifierType('cast_uuid') - airplayId → const IdentifierType
-
const IdentifierType('airplay_id') - ipAddress → const IdentifierType
-
const IdentifierType('ip_address') - unknown → const IdentifierType
-
const IdentifierType('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IdentifierType> - A constant List of the values in this enum, in order of their declaration.