ImageType enum
Enum with image types.
Values
- thumb → const ImageType
-
const ImageType('thumb') - landscape → const ImageType
-
const ImageType('landscape') - fanart → const ImageType
-
const ImageType('fanart') - logo → const ImageType
-
const ImageType('logo') - clearart → const ImageType
-
const ImageType('clearart') -
const ImageType('banner') - cutout → const ImageType
-
const ImageType('cutout') - back → const ImageType
-
const ImageType('back') - discart → const ImageType
-
const ImageType('discart') - other → const ImageType
-
const ImageType('other')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited