PlayerFeature enum
Enum with possible Player features.
Values
- power → const PlayerFeature
-
const PlayerFeature('power') - volumeSet → const PlayerFeature
-
const PlayerFeature('volume_set') - volumeMute → const PlayerFeature
-
const PlayerFeature('volume_mute') - pause → const PlayerFeature
-
const PlayerFeature('pause') - setMembers → const PlayerFeature
-
const PlayerFeature('set_members') - multiDeviceDsp → const PlayerFeature
-
const PlayerFeature('multi_device_dsp') - seek → const PlayerFeature
-
const PlayerFeature('seek') - nextPrevious → const PlayerFeature
-
const PlayerFeature('next_previous') - playAnnouncement → const PlayerFeature
-
const PlayerFeature('play_announcement') - enqueue → const PlayerFeature
-
const PlayerFeature('enqueue') - selectSoundMode → const PlayerFeature
-
const PlayerFeature('select_sound_mode') - selectSource → const PlayerFeature
-
const PlayerFeature('select_source') - options → const PlayerFeature
-
const PlayerFeature('options') - gaplessPlayback → const PlayerFeature
-
const PlayerFeature('gapless_playback') - gaplessDifferentSamplerate → const PlayerFeature
-
const PlayerFeature('gapless_different_samplerate') - playMedia → const PlayerFeature
-
const PlayerFeature('play_media') - unknown → const PlayerFeature
-
const PlayerFeature('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PlayerFeature> - A constant List of the values in this enum, in order of their declaration.