QueueOption enum
Enum representation of the queue (play) options.
Values
- play → const QueueOption
-
const QueueOption('play') - replace → const QueueOption
-
const QueueOption('replace') - next → const QueueOption
-
const QueueOption('next') - replaceNext → const QueueOption
-
const QueueOption('replace_next') - add → const QueueOption
-
const QueueOption('add') - unknown → const QueueOption
-
const QueueOption('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QueueOption> - A constant List of the values in this enum, in order of their declaration.